  Extended Verification and Validation for Earth System Models
===============================================================================

EVV is a python-based toolkit for extended verification and validation of Earth
system models (ESMs). Currently, it provides a number tests to determine if
modifications to an ESM is *climate changing.*  
  
  
  Contact
===========

If you would like to suggest features, request tests, discuss contributions,
report bugs, ask questions, or contact us for any reason, use the
[Issue Tracker](https://github.com/LIVVkit/evv4esm/issues).

Want to send us a private message?

**Joseph H. Kennedy** 
* github: @jhkennedy
* email: <a href="mailto:kennedyjh@ornl.gov">kennedyjh [at] ornl.gov</a>
